package org.omegahat.Simulation.MCMC.Examples;

import org.omegahat.Simulation.MCMC.*;
import org.omegahat.Simulation.MCMC.Proposals.*;
import org.omegahat.Simulation.MCMC.Listeners.*;
import org.omegahat.Simulation.RandomGenerators.*;
import org.omegahat.Probability.Distributions.*;

public class Binomial_BetaBinomial_SimpleExample_NKC {
  static public void main( String[] argv ) throws Throwable {

    CollingsPRNGAdministrator a = new CollingsPRNGAdministrator();
    PRNG prng = new CollingsPRNG( a.registerPRNGState() );
    
    UnnormalizedDensity target = new Binomial_BetaBinomial_SimpleLikelihood();
    
    double[][] Var =  {{ 0.003, 0.0  , 0.0  , 0.0  },
                       { 0.0  , 0.001, 0.0  , 0.0  },
                       { 0.0  , 0.0  , 0.012, 0.0  },
                       { 0.0  , 0.0  , 0.0  , 0.007}};
    
    HastingsCoupledProposal proposal = new NormalKernelProposal(Var, prng );
    
    int numComponents = 200;

    MultiDoubleState state0 = new MultiDoubleState ( numComponents );
    for(int i=0; i < numComponents/2; i++)
	state0.add( new double[]{0.903, 0.228, 0.708, 0.486 } );

    for(int i=numComponents/2; i < numComponents; i++)
	state0.add( new double[]{0.078, 0.831, 0.230, 4.5e-9 } );

    CustomHastingsCoupledSampler mcmc = 
	mcmc = new CustomHastingsCoupledSampler( state0, numComponents,
						 target, proposal, prng, 
						 false);

    ThinningProxyListener pL  = new ThinningProxyListener(numComponents);
    MCMCListenerHandle    pLh = mcmc.registerListener(pL); 

    MCMCListenerWriter l = new StrippedListenerWriter("NKC.output");
    MCMCListenerHandle lh = pL.registerListener(l1);

    mcmc.iterate( 10000 );
    
    l.close();
  }
}
 
